@@ -1,8 +1,9 @@
+"""Utilities for cprint i.e COLORS, ONCOLORS AND Exception Class"""
+
+
 class InvalidColorError(Exception):
     """Exception class for invalid colors"""
 
-    pass
-
 
 # foreground colors
 COLORS = {
